==> db-kirosake-0.3.tar.gz: db-kirosake-0.3/src/db-kirosake/dbkirosake.py <==
from github import Github
import json
import asyncio

class DBError(Exception):
    def __init__(self,message):
        super().__init__(message)

class DBKirosake():
    def __init__(self,access_token,repository):
        self.access_token=access_token
        self.repository=repository
        self.repo=Github(access_token).get_repo(repository)
       # self.dataBase=0
        
        
    async def update(self,file,rows,datas,datatype,updtype,comm='update'):
        file_content=self.repo.get_contents(file)
        db=file_content.decoded_content.decode()
        db=json.loads(db)
        
        if datatype=='str':
            db[rows]=datas
            json_object=json.dumps(db,indent=4)

        elif datatype=='int':
            if updtype=='add':
                db[rows]+=int(datas)
                json_object=json.dumps(db,indent=4)
            elif updtype=='replace':
                db[rows]=int(datas)
                json_object=json.dumps(db,indent=4)
            
        elif datatype=='float':
            if updtype=='add':
                db[rows]+=float(datas)
                json_object=json.dumps(db,indent=4)
            elif updtype=='replace':
                db[rows]=float(datas)
                json_object=json.dumps(db,indent=4)
            
        file_content = self.repo.get_contents(file)
        json_object = json.dumps(db, indent = 4)
        self.repo.update_file(file_content.path,comm, json_object, file_content.sha)
        return db
    
    
    
    async def update_more(self,file,one,two,date,datatype,updtype,comm='update'):
        file_content=self.repo.get_contents(file)
        db=file_content.decoded_content.decode()
        db=json.loads(db)
        
        if date is None:
            return 'Date is None'
        else:
            
            if datatype=='str':
                db[one][two]=date
                    
            elif datatype=='int':
                if updtype=='add':
                    db[one][two]+=int(date)
                elif updtype=='take':
                    db[one][two]-=int(date)
                elif updtype=='replace':
                    db[one][two]=int(date)
                    
            elif datatype=='float':
                if updtype=='add':
                    db[one][two]+=float(date)
                elif updtype=='take':
                    db[one][two]-=float(date)
                elif updtype=='replace':
                    db[one][two]=float(date)
                    
            elif datatype=='list':
                if updtype=='add':
                    pass
                elif updtype=='replace':
                    pass
                    
            else:
                return 'ERROR search Data Type'
        
        json_object = json.dumps(db, indent = 4)
        self.repo.update_file(file_content.path,comm, json_object, file_content.sha)
        return db
        
    
    async def update_list(self,file,list):
        db=list
        json_object=json.dumps(db,indent=4)
        file_content = self.repo.get_contents(file)
        self.repo.update_file(file_content.path,'update', json_object, file_content.sha)
        return db
    
    async def get(self,file):
        file_content=self.repo.get_contents(file)
        db=file_content.decoded_content.decode()
        db=json.loads(db)
        return db
        
    async def create(self,file,content):
        self.repo.create_file(file,'init commit',content)
        return 'Create file {file.path}'
        
    async def name_files(self,file):
        contents = self.repo.get_contents(file)
        array_file=[]
        for content_file in contents:
            array_file.append(content_file.path)
        return array_file
    
    async def delete(self,file):
        self.repo.delete_file(file.path, "remove test", file.sha)
        return 'Delete file {file.path}'
        
        
    async def create_db(self,nameDB=None,folder=None,ids=None,database=None):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if ids==None:
            raise DBError('Folder to database file is not init')
            return
        if database==None:
            raise DBError('Content with database file is not')
            return
       
        try:
            file_content=self.repo.get_contents(file)
            db=file_content.decoded_content.decode()
            db=json.loads(db)
            if str(ids) in db:
                pass
            else:
                db[ids]=database
            json_object=json.dumps(db,indent=4)
            file_content = self.repo.get_contents(file)
            self.repo.update_file(file_content.path,'update', json_object, file_content.sha)
            return db
        except:
            db={}
            db[ids]=database
            json_object = json.dumps(db, indent = 4)
            self.repo.create_file(file,'init commit',json_object)
            return 'Create file {file.path}'

==> db-kirosake-0.5.tar.gz: db-kirosake-0.5/src/db-kirosake/dbkirosake.py <==
from github import Github
import json
import asyncio

class DBError(Exception):
    def __init__(self,message):
        super().__init__(message)

class DBKirosake():
    def __init__(self,access_token,repository):
        self.access_token=access_token
        self.repository=repository
        self.repo=Github(access_token).get_repo(repository)

    
    async def create_db(self,nameDB=None,folder=None,ids=None,database=None):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if ids==None:
            raise DBError('Folder to database file is not init')
            return
        if database==None:
            raise DBError('Content with database file is not')
            return
       
        try:
            file_content=self.repo.get_contents(file)
            db=file_content.decoded_content.decode()
            db=json.loads(db)
            if str(ids) in db:
                pass
            else:
                db[ids]=database
            json_object=json.dumps(db,indent=4)
            file_content = self.repo.get_contents(file)
            self.repo.update_file(file_content.path,'update', json_object, file_content.sha)
            return db
        except:
            db={}
            db[ids]=database
            json_object = json.dumps(db, indent = 4)
            self.repo.create_file(file,'init commit',json_object)
            return 'Create file {file.path}'


    async def insert_one(
        self,nameDB=None,
        folder=None,ids=None,
        insert=None,value=None,method=None):
            
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if ids==None:
            raise DBError('Folder to database file is not init')
            return
        if insert==None:
            raise DBError('Content with database file is not')
            return
        if value==None:
            raise DBError('Value insert to file is not')
            return
        
        try:
            file_content=self.repo.get_contents(file)
            db=file_content.decoded_content.decode()
            db=json.loads(db)
            
            if method is None or method=='a' or method=='add':
                if isinstance(value, int) or isinstance(value, float):
                    db[str(ids)][str(insert)]=db[str(ids)][str(insert)]+value
                else:
                    db[str(insert)]=value
            elif method=='r' or method=='replace':
                if isinstance(value, int) or isinstance(value, float):
                    db[str(ids)][str(insert)]=value
                else:
                    db[str(insert)]=value
                    
            json_object=json.dumps(db,indent=4)
            json_object = json.dumps(db, indent = 4)
            self.repo.update_file(file_content.path,'comm', json_object, file_content.sha)
            return db
        except:
            raise DBError('Error')
        
        
    async def insert_many(
        self,nameDB=None,
        folder=None,ids=None,
        inserts=None,):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if ids==None:
            raise DBError('Folder to database file is not init')
            return
        if inserts==None:
            raise DBError('Content with database file is not')
            return
        
        try:
            file_content=self.repo.get_contents(file)
            db=file_content.decoded_content.decode()
            db=json.loads(db)
            
            for objectDB in inserts:
                try:
                    print(db[str(ids)][str(objectDB)])
                    db[str(ids)][str(objectDB)]=inserts[objectDB]
                except:
                    raise DBError(f"Object '{objectDB}' not found in database")
                    return
            json_object=json.dumps(db,indent=4)
            json_object = json.dumps(db, indent = 4)
            self.repo.update_file(file_content.path,'comm', json_object, file_content.sha)
            return db
        except:
            raise DBError('Error')
            
            
    async def get_sorted(self,nameDB=None,folder=None,key=None,reverse=True):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if key==None:
            raise DBError('Key with database file is not')
            return
        try:
            file_content=self.repo.get_contents(file)
            db=file_content.decoded_content.decode()
            db=json.loads(db)
            sortedDB=sorted(db.items(), key=lambda x: x[1][str(key)], reverse=reverse)
            return sortedDB
        except:
            raise DBError('Error')
            return


    async def get(self,nameDB=None,folder=None,ids=None):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        
        file_content=self.repo.get_contents(file)
        db=file_content.decoded_content.decode()
        db=json.loads(db)
        if ids==None:
            return db
        else:
            return db[str(ids)]
        
    async def datainfo(self,nameDB=None,folder=None,ids=None):
        if nameDB==None:
            raise DBError('Name database is not entered')
            return
        if folder==None:
            file=f'{str(nameDB)}/users.json'
        else:
            file=f'{str(nameDB)}/{str(folder)}/users.json'
        if ids==None:
            raise DBError('Key with database file is not')
            return
        file_content=self.repo.get_contents(file)
        db=file_content.decoded_content.decode()
        db=json.loads(db)
        infoDB=[
            ('size_KB',file_content.size/1000),
            ('len',len(db))
        ]
        return infoDB
